# asyncUnittest
Fully asynchronous unit test.
Define test method with 'test' in its name's lower case, starting or ending with no '_'. For example, test_connect and 
cancel_test, but _test_connect and _cancel_test will be ignored.